#!/bin/bash
##################################################
## Job run template for bwUniCluster            ##
## to run at $TMP                               ##
##################################################
## ver.  : 2014-09-09, Robert Barthel, KIT, SCC
##
## Syntax:
##   ^                         = begin of line
##   <int>                     = integer placeholder
##   ^##                       = comment
##   
##   ^#MSUB -l nodes=<int>:ppn=<int> = defines nodes and cores per node
##   ^#MSUB -l walltime=hh:mm:ss     = defines walltime in hh:mm:ss
##   ^#MSUB -N <jobname>             = defines jobname
##   ^#MSUB -m <email_option>        = defines nofication condition
##
## Note  : 
##   - all '#MSUB -?' are equivalent to 'msub -?'
##   - for more options, see 'man msub'
##   - '# MSUB' is a comment, while '#MSUB' is a msub option statement

##################################################
## HEADER: Define here your Compute resources   ##
##################################################
#MSUB -N test
#MSUB -l nodes=1:ppn=1,mem=50mb
#MSUB -l walltime=00:05:00
#MSUB -q develop
#MSUB -m n


##################################################
## BODY                                         ##
##################################################
## a) load modules if necessary
#module load compiler/intel

## b) Define your run directory and generate it
run_DIR="${TMP}/${USER}.${MOAB_JOBID:-$$}"
mkdir -pv "${run_DIR}"
 
## c) check existance of run_DIR
if [ ! -d "${run_DIR}" ] ; then
   echo "ERROR: Run DIR = ${run_DIR} does not exist"; exit 1
fi

## d) copy files from submit_DIR to run_DIR
cd $MOAB_SUBMITDIR
cp -pv do_files do_files.inp "${run_DIR}"

## e) cd to run_DIR and start "binary" together with input file
cd ${run_DIR}
./do_files do_files.inp

## f) check run status
if [ $? -ne 0 ] ; then
   echo "WARNING: do_files did not run properly"
fi 

## g) transfer files to submit directory
cp -pv files_*.out "${MOAB_SUBMITDIR}"

## h) cleanup $TMP
rm -f ${run_DIR}/*
rmdir ${run_DIR}
exit 0
